@@ -3,7 +3,7 @@ from flask_restful import Api
 
 from .resources import *
 from .update_usage import UpdateUsageResource
-
+from .parent_child import *
 bp = Blueprint("api", __name__, url_prefix="/<proxy_path>/<user_secret>/api/v1")
 api = Api(bp)
 
@@ -16,5 +16,7 @@ def init_app(app):
     api.add_resource(AllResource, "/all/")
     api.add_resource(UpdateUsageResource, "/update_usage/")
     api.add_resource(HelloResource, "/hello/")
+    api.add_resource(SyncChildResource, "/sync_child/")
+    api.add_resource(AddUsageResource, "/add_usage/")
     
     app.register_blueprint(bp)
